---
name: Bug report
about: Create a report to help us improve Gammapy!
title: ''
labels: bug
assignees: ''

---

**Gammapy version**
Please use `gammapy info` or `python -c 'import gammapy; print(gammapy.__version__)'` to check which version of Gammapy you are using, and put that information here. If the error is possibly related to the version of Python, Numpy or Astropy or another package, please also include that version information.

Are you using the latest stable version of Gammapy? (see https://gammapy.org/news.html)
If no, can you upgrade and try with the latest stable version, please?

**Bug description**
A short description what the bug is (usually 1-2 sentences)

**Expected behavior**
A clear and concise description of what you expected to happen.

**To Reproduce**
Steps to reproduce the behavior.
See https://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports

If you can't share an example that lets us reproduce the bug, it's likely that we'll need to start a guessing game and ask you for more information. The next best thing to a reproducible example is to copy & paste the code or command that caused the error, and the output you got (e.g. the full Python traceback if there's an exception).

**Other information**
Any other information you think will be useful for us to fix the issue can go here.
